@@ -3,12 +3,12 @@ package Number::Phone::JP::Table::Q2;
 use strict;
 use warnings;
 
-our $VERSION = '0.20141201';
+our $VERSION = '0.20150106';
 
-# Table last modified: 2014-12-01
+# Table last modified: 2015-01-06
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
-    990 => '(?:(?:6(?:2[013-9]|1[0-35-79])|5(?:[12]\d|04))\d{3})',
+    990 => '(?:5(?:1[36]|04|25)\d{3})',
 );
 
 1;
